@@ -26,6 +26,11 @@
 #define _VERILATED_CPP_
 #include "verilated_imp.h"
 #include <cctype>
+#include <sys/stat.h>  // mkdir
+
+#if defined(WIN32) || defined(__MINGW32__)
+# include <direct.h>  // mkdir
+#endif
 
 #define VL_VALUE_STRING_MAX_WIDTH 8192	///< Max static char array for VL_VALUE_STRING
 
@@ -38,17 +43,18 @@ VerilatedVoidCb Verilated::s_flushCb = NULL;
 
 // Keep below together in one cache line
 Verilated::Serialized Verilated::s_s;
+Verilated::NonSerialized Verilated::s_ns;
 VL_THREAD_LOCAL Verilated::ThreadLocal Verilated::t_s;
 
-struct Verilated::CommandArgValues Verilated::s_args = {0, NULL};
+Verilated::CommandArgValues Verilated::s_args;
 
-VerilatedImp  VerilatedImp::s_s;
+VerilatedImp VerilatedImp::s_s;
 
 //===========================================================================
 // User definable functions
 
 #ifndef VL_USER_FINISH		// Define this to override this function
-void vl_finish (const char* filename, int linenum, const char* hier) VL_MT_UNSAFE {
+void vl_finish(const char* filename, int linenum, const char* hier) VL_MT_UNSAFE {
     if (0 && hier) {}
     VL_PRINTF("- %s:%d: Verilog $finish\n", filename, linenum);  // Not VL_PRINTF_MT, already on main thread
     if (Verilated::gotFinish()) {
@@ -61,15 +67,15 @@ void vl_finish (const char* filename, int linenum, const char* hier) VL_MT_UNSAF
 #endif
 
 #ifndef VL_USER_STOP		// Define this to override this function
-void vl_stop (const char* filename, int linenum, const char* hier) VL_MT_UNSAFE {
+void vl_stop(const char* filename, int linenum, const char* hier) VL_MT_UNSAFE {
     Verilated::gotFinish(true);
     Verilated::flushCall();
-    vl_fatal (filename,linenum,hier,"Verilog $stop");
+    vl_fatal(filename,linenum,hier,"Verilog $stop");
 }
 #endif
 
 #ifndef VL_USER_FATAL	// Define this to override this function
-void vl_fatal (const char* filename, int linenum, const char* hier, const char* msg) VL_MT_UNSAFE {
+void vl_fatal(const char* filename, int linenum, const char* hier, const char* msg) VL_MT_UNSAFE {
     if (0 && hier) {}
     Verilated::gotFinish(true);
     VL_PRINTF("%%Error: %s:%d: %s\n", filename, linenum, msg);  // Not VL_PRINTF_MT, already on main thread
@@ -84,7 +90,7 @@ void vl_fatal (const char* filename, int linenum, const char* hier, const char*
 //===========================================================================
 // Wrapper to call certain functions via messages when multithreaded
 
-void VL_FINISH_MT (const char* filename, int linenum, const char* hier) VL_MT_SAFE {
+void VL_FINISH_MT(const char* filename, int linenum, const char* hier) VL_MT_SAFE {
 #ifdef VL_THREADED
     VerilatedThreadMsgQueue::post(VerilatedMsg([=](){
 		vl_finish(filename, linenum, hier);
@@ -94,7 +100,7 @@ void VL_FINISH_MT (const char* filename, int linenum, const char* hier) VL_MT_SA
 #endif
 }
 
-void VL_STOP_MT (const char* filename, int linenum, const char* hier) VL_MT_SAFE {
+void VL_STOP_MT(const char* filename, int linenum, const char* hier) VL_MT_SAFE {
 #ifdef VL_THREADED
     VerilatedThreadMsgQueue::post(VerilatedMsg([=](){
 		vl_stop(filename, linenum, hier);
@@ -104,7 +110,7 @@ void VL_STOP_MT (const char* filename, int linenum, const char* hier) VL_MT_SAFE
 #endif
 }
 
-void VL_FATAL_MT (const char* filename, int linenum, const char* hier, const char* msg) VL_MT_SAFE {
+void VL_FATAL_MT(const char* filename, int linenum, const char* hier, const char* msg) VL_MT_SAFE {
 #ifdef VL_THREADED
     VerilatedThreadMsgQueue::post(VerilatedMsg([=](){
 		vl_fatal(filename, linenum, hier, msg);
@@ -122,10 +128,16 @@ std::string _vl_string_vprintf(const char* formatp, va_list ap) VL_MT_SAFE {
     va_list aq;
     va_copy(aq, ap);
     int len = VL_VSNPRINTF(NULL, 0, formatp, aq);
-    if (VL_UNLIKELY(len < 1)) return "";
+    va_end(aq);
+    if (VL_UNLIKELY(len < 1)) {
+        va_end(ap);
+        return "";
+    }
 
     char* bufp = new char[len+1];
     VL_VSNPRINTF(bufp, len+1, formatp, ap);
+    va_end(ap);
+
     std::string out = std::string(bufp, len);
     delete[] bufp;
     return out;
@@ -159,7 +171,11 @@ void VL_DBG_MSGF(const char* formatp, ...) VL_MT_SAFE {
     std::string out = _vl_string_vprintf(formatp, ap);
     va_end(ap);
     // printf("-imm-V{t%d,%" VL_PRI64 "d}%s", VL_THREAD_ID(), _vl_dbg_sequence_number(), out.c_str());
-    VL_PRINTF_MT("-V{t%d,%" VL_PRI64 "d}%s", VL_THREAD_ID(), _vl_dbg_sequence_number(), out.c_str());
+
+    // Using VL_PRINTF not VL_PRINTF_MT so that we can call VL_DBG_MSGF
+    // from within the guts of the thread execution machinery (and it goes
+    // to the screen and not into the queues we're debugging)
+    VL_PRINTF("-V{t%d,%" VL_PRI64 "u}%s", VL_THREAD_ID(), _vl_dbg_sequence_number(), out.c_str());
 }
 
 #ifdef VL_THREADED
@@ -186,28 +202,24 @@ Verilated::Serialized::Serialized() {
     s_fatalOnVpiError = true; // retains old default behaviour
 }
 
-//===========================================================================
-// Random reset -- Only called at init time, so don't inline.
-
-IData VL_RAND32() VL_MT_SAFE {
-#ifdef VL_THREADED
-    static VL_THREAD_LOCAL bool t_seeded = false;
-    static VL_THREAD_LOCAL drand48_data t_buffer;
-    static VerilatedMutex s_mutex;
-    if (VL_UNLIKELY(!t_seeded)) {
-	t_seeded = true;
-	long seedval;
-	{
-	    VerilatedLockGuard guard(s_mutex);
-	    seedval = lrand48()<<16 ^ lrand48();
-	    if (!seedval) seedval++;
-	}
-	srand48_r(seedval, &t_buffer);
+Verilated::NonSerialized::NonSerialized() {
+    s_profThreadsStart = 1;
+    s_profThreadsWindow = 2;
+    s_profThreadsFilenamep = strdup("profile_threads.dat");
+}
+Verilated::NonSerialized::~NonSerialized() {
+    if (s_profThreadsFilenamep) {
+        free(const_cast<char*>(s_profThreadsFilenamep)); s_profThreadsFilenamep=NULL;
     }
-    long v0; lrand48_r(&t_buffer, &v0);
-    long v1; lrand48_r(&t_buffer, &v1);
-    return (v0<<16) ^ v1;
-#elif defined(_WIN32) && !defined(__CYGWIN__)
+}
+
+//===========================================================================
+// Random -- Mostly called at init time, so not inline.
+
+static vluint32_t vl_sys_rand32() VL_MT_UNSAFE {
+    // Return random 32-bits using system library.
+    // Used only to construct seed for Verilator's PNRG.
+#if defined(_WIN32) && !defined(__CYGWIN__)
     // Windows doesn't have lrand48(), although Cygwin does.
     return (rand()<<16) ^ rand();
 #else
@@ -215,21 +227,46 @@ IData VL_RAND32() VL_MT_SAFE {
 #endif
 }
 
+vluint64_t vl_rand64() VL_MT_SAFE {
+    static VerilatedMutex s_mutex;
+    static VL_THREAD_LOCAL bool t_seeded = false;
+    static VL_THREAD_LOCAL vluint64_t t_state[2];
+    if (VL_UNLIKELY(!t_seeded)) {
+	t_seeded = true;
+	{
+            long seedval;
+	    VerilatedLockGuard lock(s_mutex);
+            t_state[0] = (((vluint64_t)vl_sys_rand32())<<32
+                          ^ ((vluint64_t)vl_sys_rand32()));
+            t_state[1] = (((vluint64_t)vl_sys_rand32())<<32
+                          ^ ((vluint64_t)vl_sys_rand32()));
+            // Fix state as algorithm is slow to randomize if many zeros
+            // This causes a loss of ~ 1 bit of seed entropy, no big deal
+            if (VL_COUNTONES_I(t_state[0]) < 10) t_state[0] = ~t_state[0];
+            if (VL_COUNTONES_I(t_state[1]) < 10) t_state[1] = ~t_state[1];
+	}
+    }
+    // Xoroshiro128+ algorithm
+    vluint64_t result = t_state[0] + t_state[1];
+    t_state[1] ^= t_state[0];
+    t_state[0] = (((t_state[0] << 55) | (t_state[0] >> 9))
+                  ^ t_state[1] ^ (t_state[1] << 14));
+    t_state[1] = (t_state[1] << 36) | (t_state[1] >> 28);
+    return result;
+}
+
 IData VL_RANDOM_I(int obits) VL_MT_SAFE {
-    return VL_RAND32() & VL_MASK_I(obits);
+    return vl_rand64() & VL_MASK_I(obits);
 }
-
 QData VL_RANDOM_Q(int obits) VL_MT_SAFE {
-    QData data = ((QData)VL_RAND32()<<VL_ULL(32)) | (QData)VL_RAND32();
-    return data & VL_MASK_Q(obits);
+    return vl_rand64() & VL_MASK_Q(obits);
 }
-
 WDataOutP VL_RANDOM_W(int obits, WDataOutP outwp) VL_MT_SAFE {
     for (int i=0; i<VL_WORDS_I(obits); ++i) {
 	if (i<(VL_WORDS_I(obits)-1)) {
-	    outwp[i] = VL_RAND32();
+	    outwp[i] = vl_rand64();
 	} else {
-	    outwp[i] = VL_RAND32() & VL_MASK_I(obits);
+	    outwp[i] = vl_rand64() & VL_MASK_I(obits);
 	}
     }
     return outwp;
@@ -244,7 +281,6 @@ IData VL_RAND_RESET_I(int obits) VL_MT_SAFE {
     if (obits<32) data &= VL_MASK_I(obits);
     return data;
 }
-
 QData VL_RAND_RESET_Q(int obits) VL_MT_SAFE {
     if (Verilated::randReset()==0) return 0;
     QData data = VL_ULL(~0);
@@ -254,7 +290,6 @@ QData VL_RAND_RESET_Q(int obits) VL_MT_SAFE {
     if (obits<64) data &= VL_MASK_Q(obits);
     return data;
 }
-
 WDataOutP VL_RAND_RESET_W(int obits, WDataOutP outwp) VL_MT_SAFE {
     for (int i=0; i<VL_WORDS_I(obits); ++i) {
 	if (i<(VL_WORDS_I(obits)-1)) {
@@ -1357,7 +1392,7 @@ void VL_READMEM_N(
     FILE* fp = fopen(ofilenamep.c_str(), "r");
     if (VL_UNLIKELY(!fp)) {
         // We don't report the Verilog source filename as it slow to have to pass it down
-        VL_FATAL_MT (ofilenamep.c_str(), 0, "", "$readmem file not found");
+        VL_FATAL_MT(ofilenamep.c_str(), 0, "", "$readmem file not found");
         return;
     }
     // Prep for reading
@@ -1404,8 +1439,8 @@ void VL_READMEM_N(
                     //printf(" Value width=%d  @%x = %c\n", width, addr, c);
                     if (VL_UNLIKELY(addr >= static_cast<IData>(depth+array_lsb)
                                     || addr < static_cast<IData>(array_lsb))) {
-                        VL_FATAL_MT (ofilenamep.c_str(), linenum, "",
-                                     "$readmem file address beyond bounds of array");
+                        VL_FATAL_MT(ofilenamep.c_str(), linenum, "",
+                                    "$readmem file address beyond bounds of array");
                     } else {
                         int entry = addr - array_lsb;
                         QData shift = hex ? VL_ULL(4) : VL_ULL(1);
@@ -1434,15 +1469,15 @@ void VL_READMEM_N(
                             datap[0] |= value;
                         }
                         if (VL_UNLIKELY(value>=(1<<shift))) {
-                            VL_FATAL_MT (ofilenamep.c_str(), linenum, "",
-                                         "$readmemb (binary) file contains hex characters");
+                            VL_FATAL_MT(ofilenamep.c_str(), linenum, "",
+                                        "$readmemb (binary) file contains hex characters");
                         }
                     }
                 }
                 innum = true;
             }
             else {
-                VL_FATAL_MT (ofilenamep.c_str(), linenum, "", "$readmem file syntax error");
+                VL_FATAL_MT(ofilenamep.c_str(), linenum, "", "$readmem file syntax error");
             }
         }
         lastc = c;
@@ -1452,7 +1487,7 @@ void VL_READMEM_N(
     // Final checks
     fclose(fp);
     if (VL_UNLIKELY(end != VL_UL(0xffffffff) && addr != (end+1))) {
-        VL_FATAL_MT (ofilenamep.c_str(), linenum, "", "$readmem file ended before specified ending-address");
+        VL_FATAL_MT(ofilenamep.c_str(), linenum, "", "$readmem file ended before specified ending-address");
     }
 }
 
@@ -1599,7 +1634,8 @@ std::string VL_CVT_PACK_STR_NW(int lwords, WDataInP lwp) VL_MT_SAFE {
 Verilated::ThreadLocal::ThreadLocal()
     :
 #ifdef VL_THREADED
-    t_trainId(0),
+    t_mtaskId(0),
+    t_endOfEvalReqd(0),
 #endif
     t_dpiScopep(NULL), t_dpiFilename(0), t_dpiLineno(0) {
 }
@@ -1607,7 +1643,7 @@ Verilated::ThreadLocal::~ThreadLocal() {
 }
 
 void Verilated::debug(int val) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     s_s.s_debug = val;
     if (val) {
 #ifdef VL_DEBUG
@@ -1618,25 +1654,39 @@ void Verilated::debug(int val) VL_MT_SAFE {
     }
 }
 void Verilated::randReset(int val) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     s_s.s_randReset = val;
 }
 void Verilated::calcUnusedSigs(bool flag) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     s_s.s_calcUnusedSigs = flag;
 }
 void Verilated::gotFinish(bool flag) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     s_s.s_gotFinish = flag;
 }
 void Verilated::assertOn(bool flag) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     s_s.s_assertOn = flag;
 }
 void Verilated::fatalOnVpiError(bool flag) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     s_s.s_fatalOnVpiError = flag;
 }
+void Verilated::profThreadsStart(vluint64_t flag) VL_MT_SAFE {
+    VerilatedLockGuard lock(m_mutex);
+    s_ns.s_profThreadsStart = flag;
+}
+void Verilated::profThreadsWindow(vluint64_t flag) VL_MT_SAFE {
+    VerilatedLockGuard lock(m_mutex);
+    s_ns.s_profThreadsWindow = flag;
+}
+void Verilated::profThreadsFilenamep(const char* flagp) VL_MT_SAFE {
+    VerilatedLockGuard lock(m_mutex);
+    if (s_ns.s_profThreadsFilenamep) free(const_cast<char*>(s_ns.s_profThreadsFilenamep));
+    s_ns.s_profThreadsFilenamep = strdup(flagp);
+}
+
 
 const char* Verilated::catName(const char* n1, const char* n2) VL_MT_SAFE {
     // Returns new'ed data
@@ -1656,7 +1706,7 @@ const char* Verilated::catName(const char* n1, const char* n2) VL_MT_SAFE {
 }
 
 void Verilated::flushCb(VerilatedVoidCb cb) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     if (s_flushCb == cb) {}  // Ok - don't duplicate
     else if (!s_flushCb) { s_flushCb=cb; }
     else {
@@ -1666,14 +1716,14 @@ void Verilated::flushCb(VerilatedVoidCb cb) VL_MT_SAFE {
 }
 
 void Verilated::flushCall() VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(m_mutex);
     if (s_flushCb) (*s_flushCb)();
     fflush(stderr);
     fflush(stdout);
 }
 
 void Verilated::commandArgs(int argc, const char** argv) VL_MT_SAFE {
-    VerilatedLockGuard guard(m_mutex);
+    VerilatedLockGuard lock(s_args.m_argMutex);
     s_args.argc = argc;
     s_args.argv = argv;
     VerilatedImp::commandArgs(argc,argv);
@@ -1696,6 +1746,14 @@ void Verilated::overWidthError(const char* signame) VL_MT_SAFE {
     VL_FATAL_MT("unknown",0,"", msg.c_str());
 }
 
+void Verilated::mkdir(const char* dirname) VL_MT_UNSAFE {
+#if defined(_WIN32) || defined(__MINGW32__)
+    ::mkdir(dirname);
+#else
+    ::mkdir(dirname, 0777);
+#endif
+}
+
 void Verilated::quiesce() VL_MT_SAFE {
 #ifdef VL_THREADED
     // Wait until all threads under this evaluation are quiet
@@ -1711,16 +1769,6 @@ void Verilated::scopesDump() VL_MT_SAFE {
     VerilatedImp::scopesDump();
 }
 
-void Verilated::numThreads(unsigned threads) VL_MT_SAFE {
-    VerilatedImp::numThreads(threads);
-}
-unsigned Verilated::numThreads() VL_MT_SAFE {
-    return VerilatedImp::numThreads();
-}
-void Verilated::spawnThreads() VL_MT_SAFE {
-    VerilatedImp::spawnThreads();
-}
-
 const VerilatedScope* Verilated::scopeFind(const char* namep) VL_MT_SAFE {
     return VerilatedImp::scopeFind(namep);
 }
@@ -1734,8 +1782,8 @@ const VerilatedScopeNameMap* Verilated::scopeNameMap() VL_MT_SAFE {
 }
 
 #ifdef VL_THREADED
-void Verilated::endOfThreadTrainGuts(VerilatedEvalMsgQueue* evalMsgQp) VL_MT_SAFE {
-    VL_DEBUG_IF(VL_DBG_MSGF("End of thread train\n"););
+void Verilated::endOfThreadMTaskGuts(VerilatedEvalMsgQueue* evalMsgQp) VL_MT_SAFE {
+    VL_DEBUG_IF(VL_DBG_MSGF("End of thread mtask\n"););
     VerilatedThreadMsgQueue::flush(evalMsgQp);
 }
 
@@ -1745,6 +1793,96 @@ void Verilated::endOfEvalGuts(VerilatedEvalMsgQueue* evalMsgQp) VL_MT_SAFE {
 }
 #endif
 
+//===========================================================================
+// VerilatedImp:: Methods
+
+void VerilatedImp::internalsDump() VL_MT_SAFE {
+    VerilatedLockGuard lock(s_s.m_argMutex);
+    VL_PRINTF_MT("internalsDump:\n");
+    versionDump();
+    VL_PRINTF_MT("  Argv:");
+    for (ArgVec::const_iterator it=s_s.m_argVec.begin(); it!=s_s.m_argVec.end(); ++it) {
+        VL_PRINTF_MT(" %s",it->c_str());
+    }
+    VL_PRINTF_MT("\n");
+    scopesDump();
+    exportsDump();
+    userDump();
+}
+void VerilatedImp::versionDump() VL_MT_SAFE {
+    VL_PRINTF_MT("  Version: %s %s\n",
+                 Verilated::productName(), Verilated::productVersion());
+}
+
+void VerilatedImp::commandArgs(int argc, const char** argv) VL_EXCLUDES(s_s.m_argMutex) {
+    VerilatedLockGuard lock(s_s.m_argMutex);
+    s_s.m_argVec.clear();  // Always clear
+    commandArgsAddGuts(argc, argv);
+}
+void VerilatedImp::commandArgsAdd(int argc, const char** argv) VL_EXCLUDES(s_s.m_argMutex) {
+    VerilatedLockGuard lock(s_s.m_argMutex);
+    commandArgsAddGuts(argc, argv);
+}
+void VerilatedImp::commandArgsAddGuts(int argc, const char** argv) VL_REQUIRES(s_s.m_argMutex) {
+    if (!s_s.m_argVecLoaded) s_s.m_argVec.clear();
+    for (int i=0; i<argc; ++i) {
+        s_s.m_argVec.push_back(argv[i]);
+        commandArgVl(argv[i]);
+    }
+    s_s.m_argVecLoaded = true;  // Can't just test later for empty vector, no arguments is ok
+}
+void VerilatedImp::commandArgVl(const std::string& arg) {
+    if (0 == strncmp(arg.c_str(), "+verilator+", strlen("+verilator+"))) {
+        std::string value;
+        if (0) {
+        }
+        else if (arg == "+verilator+debug") {
+            Verilated::debug(4);
+        }
+        else if (commandArgVlValue(arg, "+verilator+debugi+", value/*ref*/)) {
+            Verilated::debug(atoi(value.c_str()));
+        }
+        else if (arg == "+verilator+help") {
+            versionDump();
+            VL_PRINTF_MT("For help, please see 'verilator --help'\n");
+            VL_FATAL_MT("COMMAND_LINE", 0, "", "Exiting due to command line argument (not an error)");
+        }
+        else if (commandArgVlValue(arg, "+verilator+prof+threads+start+", value/*ref*/)) {
+            Verilated::profThreadsStart(atoll(value.c_str()));
+        }
+        else if (commandArgVlValue(arg, "+verilator+prof+threads+window+", value/*ref*/)) {
+            Verilated::profThreadsWindow(atol(value.c_str()));
+        }
+        else if (commandArgVlValue(arg, "+verilator+prof+threads+file+", value/*ref*/)) {
+            Verilated::profThreadsFilenamep(value.c_str());
+        }
+        else if (commandArgVlValue(arg, "+verilator+rand+reset+", value/*ref*/)) {
+            Verilated::randReset(atoi(value.c_str()));
+        }
+        else if (arg == "+verilator+V") {
+            versionDump();  // Someday more info too
+            VL_FATAL_MT("COMMAND_LINE", 0, "", "Exiting due to command line argument (not an error)");
+        }
+        else if (arg == "+verilator+version") {
+            versionDump();
+            VL_FATAL_MT("COMMAND_LINE", 0, "", "Exiting due to command line argument (not an error)");
+        }
+        else {
+            VL_PRINTF_MT("%%Warning: Unknown +verilator runtime argument: '%s'\n", arg.c_str());
+        }
+    }
+}
+bool VerilatedImp::commandArgVlValue(const std::string& arg,
+                                     const std::string& prefix, std::string& valuer) {
+    size_t len = prefix.length();
+    if (0==strncmp(prefix.c_str(), arg.c_str(), len)) {
+        valuer = arg.substr(len);
+        return true;
+    } else {
+        return false;
+    }
+}
+
 //======================================================================
 // VerilatedSyms:: Methods
 
@@ -1868,7 +2006,7 @@ void VerilatedScope::varInsert(int finalize, const char* namep, void* datap,
     if (!finalize) return;
 
     if (!m_varsp) m_varsp = new VerilatedVarNameMap();
-    VerilatedVar var (namep, datap, vltype, (VerilatedVarFlags)vlflags, dims);
+    VerilatedVar var(namep, datap, vltype, (VerilatedVarFlags)vlflags, dims);
 
     va_list ap;
     va_start(ap,dims);
@@ -1943,7 +2081,7 @@ void VerilatedScope::scopeDump() const {
 //===========================================================================
 // VerilatedOneThreaded:: Methods
 
-#ifdef VL_THREADED
+#if defined(VL_THREADED) && defined(VL_DEBUG)
 void VerilatedAssertOneThread::fatal_different() VL_MT_SAFE {
     VL_FATAL_MT(__FILE__, __LINE__, "", "Routine called that is single threaded, but called from"
 		" a different thread then the expected constructing thread");
